@@ -45,20 +45,21 @@
 rep_sample_n <- function(tbl, size, replace = FALSE, reps = 1, prob = NULL) {
   n <- nrow(tbl)
 
-  assertive::assert_is_data.frame(tbl)
-  assertive::assert_is_numeric(size)
-  assertive::assert_is_logical(replace)
-  assertive::assert_is_numeric(reps)
+  check_type(tbl, is.data.frame)
+  check_type(size, is.numeric)
+  check_type(replace, is.logical)
+  check_type(reps, is.numeric)
   if(!is.null(prob))
-    assertive::assert_is_numeric(prob)
+    check_type(prob, is.numeric)
 
   # assign non-uniform probabilities
   # there should be a better way!!
   # prob needs to be nrow(tbl) -- not just number of factor levels
   if (!is.null(prob)) {
     if (length(prob) != n)
-      stop(paste("The argument `prob` must have length `nrow(tbl)` = ",
-                 nrow(tbl)))
+      stop_glue(
+        "The argument `prob` must have length `nrow(tbl)` = {nrow(tbl)}"
+      )
 
     prob <- dplyr::data_frame(vals = levels(dplyr::pull(tbl, 1))) %>%
       dplyr::mutate(probs = prob) %>%
