@@ -75,24 +75,25 @@ visualize <- function(data, bins = 15, method = "simulation",
                       endpoints_color = "mediumaquamarine",
                       ci_fill = "turquoise", ...) {
   
-  assertive::assert_is_data.frame(data)
-  assertive::assert_is_numeric(bins)
-  assertive::assert_is_character(method)
-  assertive::assert_is_character(dens_color)
-  assertive::assert_is_character(obs_stat_color)
-  assertive::assert_is_character(pvalue_fill)
+  check_type(data, is.data.frame)
+  check_type(bins, is.numeric)
+  check_type(method, is.character)
+  check_type(dens_color, is.character)
+  check_type(obs_stat_color, is.character)
+  check_type(pvalue_fill, is.character)
   if(!is.null(direction))
-    assertive::assert_is_character(direction)
+    check_type(direction, is.character)
   if(is.data.frame(endpoints) && 
      ( (nrow(endpoints) != 1) || (ncol(endpoints) != 2) ) ){
-    stop(paste("Expecting `endpoints` to be a 1 x 2 data frame or 2",
-                  "element vector."))
+    stop_glue(
+      "Expecting `endpoints` to be a 1 x 2 data frame or 2 element vector."
+    )
   }
   if(is.vector(endpoints) && ( length(endpoints) != 2) ) {
-    warning(paste("Expecting `endpoints` to be a 1 x 2 data frame or 2", 
-                  "element vector.",
-                  "Using the first two entries as", 
-                  "the `endpoints`."))
+    warning_glue(
+      "Expecting `endpoints` to be a 1 x 2 data frame or 2 element vector. ",
+      "Using the first two entries as the `endpoints`."
+    )
     endpoints <- endpoints[1:2]
   }
   if(is.data.frame(endpoints))
@@ -100,9 +101,10 @@ visualize <- function(data, bins = 15, method = "simulation",
   obs_stat <- check_obs_stat(obs_stat)
   if(!is.null(direction) && 
      (is.null(obs_stat) + is.null(endpoints)) != 1)
-    stop(paste("Shading requires either `endpoints` values for a", 
-               "confidence interval or the observed statistic", 
-               "`obs_stat` to be provided."))
+    stop_glue(
+      "Shading requires either `endpoints` values for a confidence interval ",
+      "or the observed statistic `obs_stat` to be provided."
+    )
 
   if(method == "simulation"){
     
@@ -132,14 +134,15 @@ visualize <- function(data, bins = 15, method = "simulation",
   } else if(method == "both"){
     
     if(!("stat" %in% names(data)))
-      stop(paste0('`generate()` and `calculate()` are both required ', 
-                  'to be done prior to `visualize(method = "both")`'))
+      stop_glue('`generate()` and `calculate()` are both required ',
+                'to be done prior to `visualize(method = "both")`')
     
     if(("replicate" %in% names(data)) &&
          length(unique(data$replicate)) < 100)
-      warning(paste("With only", length(unique(data$stat)),
-                    "replicates, it may be difficult to see the",
-                    "relationship between simulation and theory."))
+      warning_glue(
+        "With only {length(unique(data$stat))} replicates, it may be ",
+        "difficult to see the relationship between simulation and theory."
+      )
     
     infer_plot <- visualize_both(data = data, bins = bins, 
                                  dens_color = dens_color,
@@ -151,10 +154,9 @@ visualize <- function(data, bins = 15, method = "simulation",
                                  ci_fill = ci_fill,
                                  ...)
   } else {
-    stop(paste("Provide `method` with one of three options:",
-               '`"theoretical"`, `"both"`, or `"simulation"`',
-               '`"simulation"` is the default.')
-    )
+    stop_glue("Provide `method` with one of three options: ",
+              '`"theoretical"`, `"both"`, or `"simulation"`. ',
+              '`"simulation"` is the default.')
   }
   
   if(!is.null(obs_stat)){#&& !is.null(direction)
@@ -164,8 +166,8 @@ visualize <- function(data, bins = 15, method = "simulation",
   
   if(!is.null(endpoints)){
     if(!is.null(obs_stat))
-      warning(paste("Values for both `endpoints` and `obs_stat` were given",
-                  "when only one should be set. Ignoring `obs_stat` values."))
+      warning_glue("Values for both `endpoints` and `obs_stat` were given ",
+                   "when only one should be set. Ignoring `obs_stat` values.")
     infer_plot <- infer_plot +
       geom_vline(xintercept = endpoints, size = 2, 
                  color = endpoints_color, 
@@ -182,8 +184,7 @@ theory_t_plot <- function(deg_freedom, statistic_text = "t",
                           qt(0.999, deg_freedom)))) + 
     stat_function(mapping = aes(x), fun = dt, args = list(df = deg_freedom), 
                   color = dens_color) +
-    ggtitle(paste("Theoretical", statistic_text, 
-                  "Null Distribution")) +
+    ggtitle(glue_null("Theoretical {statistic_text} Null Distribution")) +
     xlab("") +
     ylab("")
 }
@@ -208,8 +209,9 @@ both_t_plot <- function(data = data, deg_freedom, statistic_text = "t",
   infer_t_plot +
     stat_function(fun = dt, args = list(df = deg_freedom), 
                   color = dens_color) +
-    ggtitle(paste("Simulation-Based and Theoretical", 
-                  statistic_text, "Null Distributions")) +
+    ggtitle(glue_null(
+      "Simulation-Based and Theoretical {statistic_text} Null Distributions"
+    )) +
     xlab("tstat") +
     ylab("")
 }
@@ -222,7 +224,7 @@ theory_anova_plot <- function(deg_freedom_top, deg_freedom_bottom,
     stat_function(mapping = aes(x), fun = df, 
                   args = list(df1 = deg_freedom_top, df2 = deg_freedom_bottom),
                   color = dens_color) +
-    ggtitle(paste("Theoretical", statistic_text, "Null Distribution")) +
+    ggtitle(glue_null("Theoretical {statistic_text} Null Distribution")) +
     xlab("") +
     ylab("")
 }
@@ -239,8 +241,9 @@ both_anova_plot <- function(data, deg_freedom_top,
                             ....){
   
   if(!is.null(direction) && !(direction %in% c("greater", "right")))
-    warning(paste("F usually corresponds to right-tailed tests. Proceed",
-                  "with caution."), call. = FALSE)
+    warning_glue(
+      "F usually corresponds to right-tailed tests. Proceed with caution."
+    )
   
   infer_anova_plot <- shade_density_check(data = data, 
                                           obs_stat = obs_stat,
@@ -254,8 +257,9 @@ both_anova_plot <- function(data, deg_freedom_top,
     stat_function(fun = df, 
                   args = list(df1 = deg_freedom_top, df2 = deg_freedom_bottom),
                   color = dens_color) +
-    ggtitle(paste("Simulation-Based and Theoretical", 
-                  statistic_text, "Null Distributions")) +
+    ggtitle(glue_null(
+      "Simulation-Based and Theoretical {statistic_text} Null Distributions"
+    )) +
     xlab("Fstat") +
     ylab("")  
 }
@@ -264,7 +268,7 @@ theory_z_plot <- function(statistic_text = "z", dens_color = dens_color,  ...){
   
   ggplot(data.frame(x = c(qnorm(0.001), qnorm(0.999)))) + 
     stat_function(mapping = aes(x), fun = dnorm, color = dens_color) +
-    ggtitle(paste("Theoretical", statistic_text, "Null Distribution")) +
+    ggtitle(glue_null("Theoretical {statistic_text} Null Distribution")) +
     xlab("") +
     ylab("")
 }
@@ -289,8 +293,9 @@ both_z_plot <- function(data, statistic_text = "z",
   
   infer_z_plot +
     stat_function(fun = dnorm, color = dens_color) +
-    ggtitle(paste("Simulation-Based and Theoretical", 
-                  statistic_text, "Null Distributions")) +
+    ggtitle(glue_null(
+      "Simulation-Based and Theoretical {statistic_text} Null Distributions"
+    )) +
     xlab("zstat") +
     ylab("")
 }
@@ -303,7 +308,7 @@ theory_chisq_plot <- function(deg_freedom,
     stat_function(mapping = aes(x), fun = dchisq, 
                   args = list(df = deg_freedom), 
                   color = dens_color) +
-    ggtitle(paste("Theoretical", statistic_text, "Null Distribution")) +
+    ggtitle(glue_null("Theoretical {statistic_text} Null Distribution")) +
     xlab("") +
     ylab("")
 }
@@ -319,8 +324,8 @@ both_chisq_plot <- function(data, deg_freedom, statistic_text = "Chi-Square",
                             ...){
   
   if(!is.null(direction) && !(direction %in% c("greater", "right")))
-     warning(paste("Chi-square usually corresponds to right-tailed tests.",
-                   "Proceed with caution."), call. = FALSE)
+    warning_glue("Chi-square usually corresponds to right-tailed tests. ",
+                 "Proceed with caution.")
   
   infer_chisq_plot <- shade_density_check(data = data,
                                           obs_stat = obs_stat,
@@ -333,8 +338,9 @@ both_chisq_plot <- function(data, deg_freedom, statistic_text = "Chi-Square",
   infer_chisq_plot +
     stat_function(fun = dchisq, args = list(df = deg_freedom), 
                   color = dens_color) +
-    ggtitle(paste("Simulation-Based and Theoretical", 
-                  statistic_text, "Null Distributions")) +
+    ggtitle(glue_null(
+      "Simulation-Based and Theoretical {statistic_text} Null Distributions"
+    )) +
     xlab("chisqstat") +
     ylab("")
 }
@@ -472,16 +478,17 @@ visualize_theoretical <- function(data,
                                   ci_fill, 
                                   ...) {
   
-  warning(paste("Check to make sure the conditions", 
-                "have been met for",
-                "the theoretical method. `infer` currently does not check",
-                "these for you."), call. = FALSE)
+  warning_glue(
+    "Check to make sure the conditions have been met for the theoretical ",
+    "method. {{infer}} currently does not check these for you."
+  )
   
   if(!is.null(attr(data, "stat")) && 
      !(attr(data, "stat") %in% c("t", "z", "Chisq", "F")))
-    warning(paste("Your `calculate`d statistic and the theoretical", 
-                  "distribution are on different scales. Displaying only", 
-                  "the theoretical distribution."))
+    warning_glue(
+      "Your `calculate`d statistic and the theoretical distribution are on ",
+      "different scales. Displaying only the theoretical distribution."
+    )
   
   if(attr(data, "theory_type") %in% 
      c("Two sample t", "Slope with t", "One sample t")){    
@@ -493,8 +500,9 @@ visualize_theoretical <- function(data,
   else if(attr(data, "theory_type") == "ANOVA"){
     
     if(!is.null(direction) && !(direction %in% c("greater", "right")))
-      warning(paste("F usually corresponds to right-tailed tests. Proceed",
-                    "with caution."))
+      warning_glue(
+        "F usually corresponds to right-tailed tests. Proceed with caution."
+      )
     
     infer_plot <- theory_anova_plot(
       deg_freedom_top = attr(data, "distr_param"), 
@@ -513,8 +521,8 @@ visualize_theoretical <- function(data,
           c("Chi-square test of indep", "Chi-square Goodness of Fit")){   
     
     if(!is.null(direction) && !(direction %in% c("greater", "right")))
-      warning(paste("Chi-square usually corresponds to right-tailed tests.",
-                    "Proceed with caution."))
+      warning_glue("Chi-square usually corresponds to right-tailed tests. ",
+                   "Proceed with caution.")
     
     infer_plot <- theory_chisq_plot(deg_freedom = attr(data, "distr_param"),
                                     statistic_text = "Chi-Square",
@@ -522,8 +530,9 @@ visualize_theoretical <- function(data,
   }
   
 #  else
-#    stop(paste0("'", attr(data, "theory_type"), "' is not implemented",
-#                "(possibly yet)."))
+#    stop_glue(
+#      '"{attr(data, "theory_type")}" is not implemented (possibly yet).'
+#    )
   
   # Move into its own function
   
@@ -587,14 +596,14 @@ visualize_both <- function(data, bins,
                            endpoints, 
                            ci_fill, ...) {
   
-  warning(paste("Check to make sure the conditions", 
-                "have been met for",
-                "the theoretical method. `infer` currently does not check",
-                "these for you."), call. = FALSE)
+  warning_glue(
+    "Check to make sure the conditions have been met for the theoretical ",
+    "method. `infer` currently does not check these for you."
+  )
   
   if(!(attr(data, "stat") %in% c("t", "z", "Chisq", "F")))
-    stop(paste("Your `calculate`d statistic and the theoretical distribution",
-               "are on different scales. Use a standardized `stat` instead."))
+    stop_glue("Your `calculate`d statistic and the theoretical distribution ",
+              "are on different scales. Use a standardized `stat` instead.")
   
   if(attr(data, "theory_type") %in% c("Two sample t", "Slope with t")){
     
@@ -654,7 +663,7 @@ visualize_both <- function(data, bins,
   }
   
 #  else
-#    stop(paste0("'", attr(data, "theory_type"), "' is not implemented yet."))
+#    stop_glue('"{attr(data, "theory_type")}" is not implemented yet.')
   
   infer_plot
 }
